@@ -278,20 +278,20 @@ if __name__ == '__main__':
     # 初始化发布队列 fliter_rep=True任务自动去重
     redis_pub = RedisPublish(queue_name=quenen_name, fliter_rep=False, max_push_size=50)
 
-    result = [str(i) for i in range(1, 1001)]
+    result = [str(i) for i in range(1, 101)]
 
 
     def print_msg_str(msg):
         print(f"msg_str:{msg}")
 
 
-    for zz in result:
-        redis_pub.publish_redispy_str(zz)  # 写入字符串任务
-
-    # 多线程消费字符串任务
-    redis_customer = RedisCustomer(quenen_name, consuming_function=print_msg_str, process_num=2, threads_num=100,
-                                   max_retry_times=5, qps=10)
-    redis_customer.start_consuming_message()
+    # for zz in result:
+    #     redis_pub.publish_redispy_str(zz)  # 写入字符串任务
+    #
+    # # 多线程消费字符串任务
+    # redis_customer = RedisCustomer(quenen_name, consuming_function=print_msg_str, process_num=2, threads_num=100,
+    #                                max_retry_times=5, qps=10)
+    # redis_customer.start_consuming_message()
 
     for zz in result:
         redis_pub.publish_redispy(c=zz, b=zz, a=zz)  # 写入字典任务 {"c":zz,"b":zz,"a":zz}
@@ -304,6 +304,6 @@ if __name__ == '__main__':
 
 
     # 多线程消费字典任务
-    redis_customer = RedisCustomer(quenen_name, consuming_function=print_msg_dict, process_num=1, threads_num=100,
-                                   max_retry_times=5, is_support_mutil_param=True, qps=10)
+    redis_customer = RedisCustomer(quenen_name, consuming_function=print_msg_dict, process_num=5, threads_num=100,
+                                   max_retry_times=5, is_support_mutil_param=True, qps=50)
     redis_customer.start_consuming_message()
